PCB Environment: ActionTab Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
ActionTab Class Reference
Inheritance diagram for ActionTab:

## Public Member Functions
bool | init ()
void | connect (Window &, UIActions &)
uint | getLayer () const
uint64_t | getTimeoutMS () const
void | setBoard (const PCBoard *)
void | setNumLayers (uint N)
void | setPins (const Pin *, const Pin *)
void | setProgress (uint)
void | setActiveTool (char)
void | newSelections ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ActionTab.hpp